==> hguatlas13k_1.10.0.tar.gz: hguatlas13k/man/hguatlas13kPATH2PROBE.Rd <==
\name{hguatlas13kPATH2PROBE}
\alias{hguatlas13kPATH2PROBE}
\title{Map between Kyoto Encyclopedia of Genes and Genomes (KEGG)
  pathway identifiers and Manufacturer Identifiers}
\description{
 hguatlas13kPATH2PROBE is an R environment that provides mappings between
 KEGG ids and manufacturer ids.
}
\details{
  Each KEGG id is mapped to a named vector of manufacturer ids. The name
  represents the KEGG id and the vector contains all manufacturer ids
  that are found in that particular pathway. An \code{NA} is reported
  for any KEGG id that cannot be mapped to any manufacturer ids.

  Pathway name for a given pathway id can be obtained using the KEGG
  data package that can either be built using AnnBuilder or downloaded
  from Bioconductor \url{http://www.bioconductor.org}.

  Graphic presentations of pathways are searchable at
  \url{http://www.genome.ad.jp/kegg/pathway.html} using pathway ids as keys.
  
  Mappings were based on data provided by:

  KEGG:\url{http://gopher5/compbio/annotationSourceData/kegg/pathways}. Built: Release 36.0, October 1, 2005

  Entrez Gene:\url{http://gopher5/compbio/annotationSourceData/ftp.ncbi.nlm.nih.gov/gene/DATA/}. Built: Source data downloaded from Entrez Gene on Tue Oct  4 18:56:39 2005

  Package built Tue Oct  4 19:12:19 2005
}
\references{
\url{http://www.genome.ad.jp/kegg/}
}
\examples{
    # Convert the environment to a list
    xx <- as.list(hguatlas13kPATH2PROBE)
    # Remove pathway ids that do not map to any probe id
    xx <- xx[!is.na(xx)]
    if(length(xx) > 0){
        # The probe ids for the first two elements of XX
        xx[1:2]
        # Get the first one
        xx[[1]]
    } 
}

\keyword{datasets}

==> hguatlas13k_1.12.0.tar.gz: hguatlas13k/man/hguatlas13kPATH2PROBE.Rd <==
\name{hguatlas13kPATH2PROBE}
\alias{hguatlas13kPATH2PROBE}
\title{Map between Kyoto Encyclopedia of Genes and Genomes (KEGG)
  pathway identifiers and Manufacturer Identifiers}
\description{
 hguatlas13kPATH2PROBE is an R environment that provides mappings between
 KEGG ids and manufacturer ids.
}
\details{
  Each KEGG id is mapped to a named vector of manufacturer ids. The name
  represents the KEGG id and the vector contains all manufacturer ids
  that are found in that particular pathway. An \code{NA} is reported
  for any KEGG id that cannot be mapped to any manufacturer ids.

  Pathway name for a given pathway id can be obtained using the KEGG
  data package that can either be built using AnnBuilder or downloaded
  from Bioconductor \url{http://www.bioconductor.org}.

  Graphic presentations of pathways are searchable at
  \url{http://www.genome.ad.jp/kegg/pathway.html} using pathway ids as keys.
  
  Mappings were based on data provided by:

  KEGG:\url{ftp://ftp.genome.ad.jp/pub/kegg/tarfiles/pathway.tar.gz}. Built: Release 37.0, January 4, 2006

  Entrez Gene:\url{ftp://ftp.ncbi.nlm.nih.gov/gene/DATA/}. Built: Source data downloaded from Entrez Gene on Sat Mar 25 21:53:08 2006

  Package built Sat Mar 25 22:15:12 2006
}
\references{
\url{http://www.genome.ad.jp/kegg/}
}
\examples{
    # Convert the environment to a list
    xx <- as.list(hguatlas13kPATH2PROBE)
    # Remove pathway ids that do not map to any probe id
    xx <- xx[!is.na(xx)]
    if(length(xx) > 0){
        # The probe ids for the first two elements of XX
        xx[1:2]
        # Get the first one
        xx[[1]]
    } 
}

\keyword{datasets}
